pub type ProxyUrl = Redacted<Url, UrlPasswordRedactor>;Expand description
A proxy URL with the password component redacted in Debug and Display output.
Aliased Type
pub struct ProxyUrl { /* private fields */ }pub type ProxyUrl = Redacted<Url, UrlPasswordRedactor>;A proxy URL with the password component redacted in Debug and Display output.
pub struct ProxyUrl { /* private fields */ }